import React, { useState, useMemo } from 'react';
import { Link } from 'react-router-dom';
import { Calendar, User, Tag, Rss } from 'lucide-react';
import { Button } from "@/components/ui/button";
import { Badge } from "@/components/ui/badge";
import { Helmet } from 'react-helmet-async';
import { blogPosts, BlogPost } from '@/data/blogPosts';

const Blog = () => {
  const [searchQuery, setSearchQuery] = useState('');
  const [categoryFilter, setCategoryFilter] = useState('All');

  const filteredPosts = useMemo(() => {
    let filtered = blogPosts;

    if (searchQuery) {
      filtered = filtered.filter(post =>
        post.title.toLowerCase().includes(searchQuery.toLowerCase()) ||
        post.summary.toLowerCase().includes(searchQuery.toLowerCase()) ||
        post.content.toLowerCase().includes(searchQuery.toLowerCase())
      );
    }

    if (categoryFilter !== 'All') {
      filtered = filtered.filter(post => post.category === categoryFilter);
    }

    return filtered;
  }, [searchQuery, categoryFilter]);

  return (
    <>
      <Helmet>
        <title>Blog - Marketing Insights & Creator Guides | Lunora Aura</title>
        <meta name="description" content="Get the latest insights on influencer marketing, creator partnerships, and brand growth strategies from industry experts at Lunora Aura." />
        <meta property="og:title" content="Blog - Marketing Insights & Creator Guides | Lunora Aura" />
        <meta property="og:description" content="Get the latest insights on influencer marketing, creator partnerships, and brand growth strategies from industry experts at Lunora Aura." />
        <meta property="og:type" content="website" />
        <meta property="og:url" content="https://lunoraaura.com/blog" />
        <link rel="alternate" type="application/rss+xml" title="Lunora Aura Blog RSS Feed" href="https://lunoraaura.com/blog/rss.xml" />
      </Helmet>
      
      <div className="min-h-screen bg-gradient-to-br from-purple-50 via-pink-50 to-orange-50">
        {/* Header */}
        <header className="bg-white/80 backdrop-blur-md border-b border-purple-100 sticky top-0 z-50">
          <div className="container mx-auto px-4 py-4 flex justify-between items-center">
            <Link to="/" className="text-2xl font-serif font-bold text-purple-900 hover:text-purple-700 transition-colors">
              Lunora Aura
            </Link>
            <nav className="hidden md:flex space-x-6">
              <Link to="/" className="text-purple-700 hover:text-purple-900 transition-colors">Home</Link>
              <Link to="/creator-bench" className="text-purple-700 hover:text-purple-900 transition-colors">Creator Bench</Link>
              <Link to="/blog" className="text-purple-700 hover:text-purple-900 transition-colors font-semibold">Blog</Link>
              <Link to="/sitemap" className="text-purple-700 hover:text-purple-900 transition-colors">Sitemap</Link>
              <a href="/blog/rss.xml" className="text-purple-700 hover:text-purple-900 transition-colors flex items-center" title="RSS Feed">
                <Rss className="w-4 h-4" />
              </a>
            </nav>
          </div>
        </header>

        {/* Hero Section */}
        <section className="relative py-20 text-center overflow-hidden">
          <div className="container mx-auto px-4 relative z-10">
            <h1 className="text-4xl md:text-6xl font-serif font-bold text-gray-900 mb-6">
              Marketing Insights & <br />
              <span className="bg-gradient-to-r from-purple-600 to-pink-600 bg-clip-text text-transparent">
                Creator Guides
              </span>
            </h1>
            <p className="text-xl text-gray-600 max-w-3xl mx-auto mb-8">
              Stay ahead of the creator economy with actionable strategies, industry trends, and growth tactics for brands and creators alike.
            </p>
            <div className="flex justify-center items-center space-x-4">
              <a 
                href="/blog/rss.xml" 
                className="inline-flex items-center px-6 py-3 bg-white/60 backdrop-blur-sm border border-purple-200 rounded-full text-purple-700 hover:bg-purple-50 transition-all duration-300 font-medium"
              >
                <Rss className="w-4 h-4 mr-2" />
                Subscribe to RSS
              </a>
            </div>
          </div>
        </section>

        {/* Search and Filter Bar */}
        <section className="bg-white/60 backdrop-blur-sm py-8 border-b border-purple-100">
          <div className="container mx-auto px-4 flex flex-col md:flex-row items-center justify-between space-y-4 md:space-y-0 md:space-x-4">
            <input
              type="text"
              placeholder="Search articles..."
              className="w-full md:w-auto px-4 py-2 rounded-full border border-purple-200 focus:ring-purple-500 focus:border-purple-500 text-gray-700"
              value={searchQuery}
              onChange={(e) => setSearchQuery(e.target.value)}
            />
            <div className="flex items-center space-x-2 text-gray-600">
              <label htmlFor="category" className="mr-2">Filter by Category:</label>
              <select
                id="category"
                className="px-4 py-2 rounded-full border border-purple-200 focus:ring-purple-500 focus:border-purple-500 text-gray-700"
                value={categoryFilter}
                onChange={(e) => setCategoryFilter(e.target.value)}
              >
                <option value="All">All Categories</option>
                {[...new Set(blogPosts.map(post => post.category))].map(category => (
                  <option key={category} value={category}>{category}</option>
                ))}
              </select>
            </div>
          </div>
        </section>

        {/* Blog Posts Grid */}
        <section className="py-12">
          <div className="container mx-auto px-4">
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
              {filteredPosts.map(post => (
                <article key={post.id} className="bg-white/60 backdrop-blur-sm rounded-2xl p-6 border border-purple-100 hover:border-purple-200 transition-all duration-300 shadow-sm">
                  <Link to={`/blog/${post.slug}`}>
                    <img
                      src={post.image}
                      alt={post.title}
                      className="w-full h-48 object-cover rounded-xl mb-4"
                    />
                    <h2 className="text-xl font-serif font-semibold text-gray-900 mb-2 hover:text-purple-700 transition-colors">
                      {post.title}
                    </h2>
                  </Link>
                  <p className="text-gray-600 mb-4">{post.summary}</p>
                  <div className="flex items-center justify-between text-gray-500 text-sm">
                    <div className="flex items-center space-x-2">
                      <Calendar className="w-4 h-4" />
                      <span>{post.date}</span>
                    </div>
                    <div className="flex items-center space-x-2">
                      <User className="w-4 h-4" />
                      <span>{post.author}</span>
                    </div>
                  </div>
                  <div className="mt-4">
                    {post.tags.map(tag => (
                      <Badge key={tag} className="mr-2 bg-purple-100 text-purple-600 border-none">{tag}</Badge>
                    ))}
                  </div>
                </article>
              ))}
            </div>
          </div>
        </section>

        {/* Footer */}
        <footer className="bg-gray-900 text-white py-8 mt-16">
          <div className="container mx-auto px-4 text-center">
            <p className="text-gray-400">
              © 2025 Lunora Aura. All rights reserved.
            </p>
          </div>
        </footer>
      </div>
    </>
  );
};

export default Blog;
